#!/usr/bin/env python3
from jdMinecraftLauncher.jdMinecraftLauncher import main
main()

